package	jp.co.sds_corp.util.daemon.config;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.config.UnspecifiedPropertyException;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* 設定ファイルを読み込む為のサポートツールを提供します。
*/
public final class ConfigUtility
{
	static CmnLogger logger = CmnLogFactory.getInstance().getLogger(ConfigUtility.class);

    /**
    * IConfigurationの"class"属性で指定されたクラスをインスタンス化します。
    */
    public static Object createInstance(IConfiguration config)
                throws UnspecifiedPropertyException,
                       ServiceInstantiationException {
        String className = config.getAttributes().get("class");
        try {
            return Class.forName(className).newInstance();
        } catch ( Throwable ex ) {
            logger.warn( "[" + className + "] creation failed." );
            throw new ServiceInstantiationException(
                    "[" + className + "] creation failed.", ex );
        }
    }

    private ConfigUtility() {}
}
