package	jp.co.sds_corp.util.daemon.file;

import java.io.File;
import java.util.List;
import java.util.Vector;

import jp.co.sds_corp.util.daemon.AbstractService;

/**
* ファイルの受信処理を行なう抽象クラスです。
* FileChecker から起動されます。
*/
public abstract class AbstractFileProcessor extends AbstractService
	implements IFileProcessor
{
	private File dir;
	private Vector<IFilenameFilter>	vecFlt = new Vector<IFilenameFilter>();

	/**
	* 検索するディレクトリを設定します。
	* @param	dir		検索するディレクトリ
	*/
	public void setDirectory( File dir ) {
		this.dir = dir;
	}
	/**
	* 検索するディレクトリを設定します。
	* @param	dir		検索するディレクトリ
	*/
	public void setDirectory( String dir ) {
		this.dir = new File( dir );
	}
	/**
	* 検索するディレクトリを取得します。
	* @return	検索するディレクトリ
	*/
	public File getDirectory() {
		return dir;
	}

	/**
	* 検索するフィルタを追加します。
	* @param	filter	検索するフィルタ
	*/
	public void addFilter( IFilenameFilter filter ) {
		vecFlt.add( filter );
	}
	/**
	* 検索するフィルタを削除します。
	* @param	filter	検索するフィルタ
	*/
	public void removeFilter( IFilenameFilter filter ) {
		vecFlt.remove( filter );
	}
	/**
	* 検索するフィルタを取得します。
	* @return	検索するフィルタ
	*/
	public List<IFilenameFilter> listFilter() {
		return vecFlt;
	}

	/**
	* 起動された最後に呼び出されます。
	*/
	public void endOfList() {
	}

	/**
	* 処理を開始します。
	*/
	public void start() {
	}

	/**
	* 処理を停止します。
	*/
	public void stop() {
	}

}
