package	jp.co.sds_corp.util.daemon.remote.jms;

import java.util.Map;

import javax.jms.JMSException;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.remote.IRemoteClient;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;
import jp.co.sds_corp.util.msg.IMessage;
import jp.co.sds_corp.util.msg.IMessageAdapter;
import jp.co.sds_corp.util.msg.MessageAdapterFactory;

/**
* デーモンのJMS I/Fのクライアントです。
* DaemonManagerが使用するXMLファイルから、JMSのキュー情報を取得し
* DaemonManagerにコマンドを送信します。
*/
public class JMSClient implements IRemoteClient
{
	CmnLogger logger = CmnLogFactory.getInstance().getLogger(this);
	IMessageAdapter	adapter;
	String	send;
	String	recv;
	int	timeout;	// タイムアウト
	boolean	connected = false;	// 接続しているか


	/**
	* クライアントのタイプを返します。
	*/
	public String getType() {
		return "JMS";
	}

	/**
	* デーモンマネージャの JMSクライアントを初期化します。
	* @param    config  設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		MessageAdapterFactory factory = new MessageAdapterFactory();
		adapter = factory.connect( config );
		timeout = Integer.valueOf( config.get( "timeout", "5000" )).intValue();

		recv = config.get( "Send" );
		send = config.get( "Receive" );
		adapter.createReceiver( recv, null, true );
		adapter.createSender( send );
/*
@@@ 空読み
		adapter.setSoTimeout( 1000 );
		for ( ;; ) {
			IMessage res = adapter.receiveMessage();
			if ( res == null ) {
logger.debug( "break" );
				break;
			}
logger.debug( "dum" );
		}
*/
		adapter.setReceiveTimeout( 10000 );
		adapter.start();
	}

	/**
	* 接続を開始します。
	*/
	public void connect() throws Exception {
	}
	/**
	* 接続を終了します。
	*/
	public void disconnect() throws Exception {
	}

	/**
	* 接続しているかを設定します。
	* @param	var		設定するデータ
	*/
	public void setConnected( boolean var ) {
		this.connected = var;
	}
	/**
	* 接続しているかを取得します。
	* @return	接続しているか
	*/
	public boolean isConnected() {
		return connected;
	}

	/**
	* リモートのメソッドを呼び出します。
	* @param    cmd     メソッド名
	* @param    cls     パラメータのクラス
	* @param    prm     パラメータのオブジェクト
	*/
	public Object execRemote( String cmd, Class<?>[] cls, Object[] prm )
		throws Exception
	{
		IMessage msg = adapter.createMessage( IMessage.Type.MAP );
		msg.setObject( "command", cmd );
		Object ret = null;
		try {
			IMessage res = adapter.writeMessage( msg, timeout );
			ret = ((Map )res.getObject()).get( "response" );
		} catch ( Exception ex ) {
			ret = ex;
		}
		return ret;
	}

	/**
	* リモートのメソッドを呼び出します。
	* @param    cmd     メソッド名
	*/
	public Object execRemote( String cmd )
		throws Exception
	{
		Object ret = execRemote( cmd, null, null );
		return ret;
	}

	/**
	* JMSクライアントを終了します。
	*/
	public void exit() {
		try {
			adapter.stop();
		} catch ( JMSException je ) {
			Exception le = je.getLinkedException();
			if ( le != null ) {
				logger.error( "linked exception:", le );
			}
			logger.error( "stop error", je );
		} catch ( Exception ex ) {
			logger.error( "stop error", ex );
		}
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param    config  設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "type", "JMS" );
		adapter.saveConfig( config );
		config.addChild( "timeout", String.valueOf( timeout ));
		config.addChild( "Send", recv );
		config.addChild( "Receive", send );
	}

	/**
	* このクライアントの文字列表現を返します。
	* @return   クライアントの文字列表現
	*/
	public String toString() {
		String ret = "JMSClient adapter=" + adapter
						+ " send=" + send + " recv=" + recv;
		return ret;
	}

}

