package	jp.co.sds_corp.util.daemon.util.msg;

import jp.co.sds_corp.util.common.DumpTool;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;
import jp.co.sds_corp.util.msg.IMessage;
import jp.co.sds_corp.util.msg.IMessageAdapter;
import jp.co.sds_corp.util.msg.IReceiveListener;
import jp.co.sds_corp.util.msg.MessageAdapterFactory;

/**
<PRE>
<Adapter class="">
</Adapter>
</PRE>
*/
public class MessageReceiver extends AbstractService implements IReceiveListener
{
	CmnLogger logger = CmnLogFactory.getInstance().getLogger(this);
	IMessageAdapter	adapter;
	boolean	dump = false;
	DumpTool dumpTool = new DumpTool();

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		IConfiguration msgCfg = config.getChild( "Adpater" );
		MessageAdapterFactory fac = new MessageAdapterFactory();
		adapter = fac.connect( msgCfg );
		adapter.addReceiveListener( this );
		adapter.createReceiver( null, false );

		String var;
		var = config.get( "dump", "false" );
		if ( var.equals( "true" )) {
			dump = true;
		}
	}

	/**
	* 処理を開始します。
	*/
	public void start() {
		try {
			adapter.start();
		} catch ( Exception ex ) {
			logger.error( "message start error", ex );
			return;
		}
		for ( ;; ) {
			try {
				if ( isInterrupted()) {
					break;
				}
				Thread.sleep( 1000 );
			} catch ( InterruptedException iex ) {
				break;
			}
		}
	}

	public void onMessage( IMessageAdapter adapter, IMessage message ) {
		try {
			String buf = message.getObject().toString();
			if ( isDump()) {
				buf += "\n";
				buf += dumpTool.dump( buf.getBytes( "8859_1" ));
			}
			logger.debug( buf );
		} catch ( Exception ex ) {
			logger.error( "receive error", ex );
		}
	}

	/**
	* 処理を終了します。
	*/
	public void stop() {
		try {
			adapter.stop();
			adapter.close();
		} catch ( Exception ex ) {
			logger.error( "message stop error", ex );
		}
	}

	public void setDump( boolean var ) {
		this.dump = var;
	}
	public boolean isDump() {
		return this.dump;
	}

}
